import { useState, useEffect } from 'react';
import { useGame } from '../context/GameContext';
import { FontAwesomeIcon } from '@fortawesome/react-fontawesome';
import { faUsers, faGear, faPlay, faCopy, faSignOutAlt } from '@fortawesome/free-solid-svg-icons';

const LobbyScreen = () => {
  const { lobby, currentPlayer, isHost, updateSettings, startGame, leaveLobby } = useGame();
  const [showSettings, setShowSettings] = useState(false);
  const [settings, setSettings] = useState({
    songsPerPlayer: 4,
    maxPlayers: 10,
    requireYoutubeLinks: true
  });
  const [copied, setCopied] = useState(false);

  useEffect(() => {
    if (lobby && lobby.settings) {
      setSettings(lobby.settings);
    }
  }, [lobby]);

  const handleCopyCode = () => {
    if (lobby) {
      navigator.clipboard.writeText(lobby.id);
      setCopied(true);
      setTimeout(() => setCopied(false), 2000);
    }
  };

  const handleSettingsChange = (e) => {
    const { name, value, type, checked } = e.target;
    const newValue = type === 'checkbox' ? checked : type === 'number' ? parseInt(value) : value;
    
    setSettings({
      ...settings,
      [name]: newValue
    });
  };

  const handleSaveSettings = () => {
    updateSettings(settings);
    setShowSettings(false);
  };

  const handleStartGame = () => {
    startGame();
  };

  if (!lobby) return null;

  return (
    <div className="lobby-screen">
      <header className="lobby-header">
        <h1>Game Lobby</h1>
        <div className="lobby-code">
          <p>Game Code: <span className="code">{lobby.id}</span></p>
          <button className="btn icon" onClick={handleCopyCode}>
            <FontAwesomeIcon icon={faCopy} />
            {copied ? 'Copied!' : 'Copy'}
          </button>
        </div>
      </header>
      
      <div className="lobby-content">
        <div className="players-list">
          <h2><FontAwesomeIcon icon={faUsers} /> Players ({lobby.players.length})</h2>
          <ul>
            {lobby.players.map(player => (
              <li key={player.id} className={`player ${!player.isConnected ? 'disconnected' : ''} ${player.id === lobby.hostId ? 'host' : ''}`}>
                {player.name} {player.id === lobby.hostId && '(Host)'} {player.id === currentPlayer.id && '(You)'} 
                {!player.isConnected && <span className="status-disconnected">(Disconnected)</span>}
              </li>
            ))}
          </ul>
        </div>
        
        <div className="lobby-info">
          <div className="settings-preview">
            <h3><FontAwesomeIcon icon={faGear} /> Game Settings</h3>
            <p>Songs per player: {settings.songsPerPlayer}</p>
            <p>Max players: {settings.maxPlayers}</p>
            <p>YouTube links required: {settings.requireYoutubeLinks ? 'Yes' : 'No'}</p>
            
            {isHost && (
              <button className="btn secondary" onClick={() => setShowSettings(true)}>
                Edit Settings
              </button>
            )}
          </div>
          
          <div className="actions">
            {isHost && (
              <button 
                className="btn primary"
                onClick={handleStartGame}
                disabled={lobby.players.length < lobby.settings.minPlayers}
              >
                <FontAwesomeIcon icon={faPlay} /> Start Game
              </button>
            )}
            <button className="btn danger" onClick={leaveLobby}>
              <FontAwesomeIcon icon={faSignOutAlt} /> Leave Lobby
            </button>
          </div>
          
          {lobby.players.length < lobby.settings.minPlayers && isHost && (
            <p className="warning">Need at least {lobby.settings.minPlayers} players to start</p>
          )}
        </div>
      </div>
      
      {showSettings && (
        <div className="modal-overlay">
          <div className="modal">
            <h2>Game Settings</h2>
            
            <div className="form-group">
              <label htmlFor="songsPerPlayer">Songs per player</label>
              <input
                type="number"
                id="songsPerPlayer"
                name="songsPerPlayer"
                min="1"
                max="10"
                value={settings.songsPerPlayer}
                onChange={handleSettingsChange}
              />
            </div>
            
            <div className="form-group">
              <label htmlFor="maxPlayers">Maximum players</label>
              <input
                type="number"
                id="maxPlayers"
                name="maxPlayers"
                min="3"
                max="20"
                value={settings.maxPlayers}
                onChange={handleSettingsChange}
              />
            </div>
            
            <div className="form-group checkbox">
              <label htmlFor="requireYoutubeLinks">
                <input
                  type="checkbox"
                  id="requireYoutubeLinks"
                  name="requireYoutubeLinks"
                  checked={settings.requireYoutubeLinks}
                  onChange={handleSettingsChange}
                />
                Require YouTube links
              </label>
            </div>
            
            <div className="modal-actions">
              <button className="btn secondary" onClick={() => setShowSettings(false)}>
                Cancel
              </button>
              <button className="btn primary" onClick={handleSaveSettings}>
                Save Settings
              </button>
            </div>
          </div>
        </div>
      )}
    </div>
  );
};

// Ensure explicit default export
export default LobbyScreen;
